Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2082)

Unified Diff: device/sensors/sensor_manager_chromeos_unittest.cc

Issue 2646093002: Move //content/browser/device_sensor/ into device/sensors (Closed)
Patch Set: gn format & code rebase Created 3 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « device/sensors/sensor_manager_chromeos.cc ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: device/sensors/sensor_manager_chromeos_unittest.cc
diff --git a/content/browser/device_sensors/sensor_manager_chromeos_unittest.cc b/device/sensors/sensor_manager_chromeos_unittest.cc
similarity index 97%
rename from content/browser/device_sensors/sensor_manager_chromeos_unittest.cc
rename to device/sensors/sensor_manager_chromeos_unittest.cc
index 7a15eb81ce449ebe2d4a93181c2b9d274982f4c4..10b95a212d10f8c2a457b659dc40bad2e8175df0 100644
--- a/content/browser/device_sensors/sensor_manager_chromeos_unittest.cc
+++ b/device/sensors/sensor_manager_chromeos_unittest.cc
@@ -2,7 +2,7 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#include "content/browser/device_sensors/sensor_manager_chromeos.h"
+#include "device/sensors/sensor_manager_chromeos.h"
#include <memory>
@@ -16,10 +16,10 @@ namespace {
const double kMeanGravity = -9.80665;
// Isolated content::SensorManagerChromeOS from the active
// chromeos::AccelerometerReader. This allows for direct control over which
// accelerometer events are provided to the sensor manager.
-class TestSensorManagerChromeOS : public content::SensorManagerChromeOS {
+class TestSensorManagerChromeOS : public device::SensorManagerChromeOS {
public:
TestSensorManagerChromeOS() {}
~TestSensorManagerChromeOS() override {};
@@ -34,7 +34,7 @@ class TestSensorManagerChromeOS : public content::SensorManagerChromeOS {
} // namespace
-namespace content {
+namespace device {
class SensorManagerChromeOSTest : public testing::Test {
public:
@@ -226,4 +226,4 @@ TEST_F(SensorManagerChromeOSTest, BeforeRightEdgeBoundary) {
EXPECT_FLOAT_EQ(45.0f, orientation->data.gamma);
}
-} // namespace content
+} // namespace device
« no previous file with comments | « device/sensors/sensor_manager_chromeos.cc ('k') | no next file » | no next file with comments »

Powered by Google App Engine
@@ -16,10 +16,10 @@ namespace {
const double kMeanGravity = -9.80665;
-// Isolated content::SensorManagerChromeOS from the active
+// Isolated device::SensorManagerChromeOS from the active
// chromeos::AccelerometerReader. This allows for direct control over which
// accelerometer events are provided to the sensor manager.
This is Rietveld 408576698